##  Configuring Fields
To configure a field, select it and adjust the parameters as needed in the right-side panel. Configuration parameters vary based on the field type.
  * On the Configuration tab on the right-side panel, you can view and configure the following attributes:
    * Key: This is a unique identifier for each field. Once set, the key cannot be changed. Keys are crucial when setting up integrations and working with data through APIs. When creating custom fields, use meaningful key names.
    * Field type: This parameter determines the data type of the field. Once set, the field type cannot be changed. For detailed information, see [Field Types](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__field_types).
    * Displayed as: This parameter defines how the field is displayed on a fact sheet. The available display options are determined by the field type.
    * Field width: Field width, ranging from XS to XXL, helps align fields on the fact sheet page. For additional information, see [Field Width](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__field_width).
    * Other fields based on the field type.
  * Translations: On the Translations tab, you can add and modify translations for the field label and help text. To streamline the process, you can use AI-supported translation. For more information, see [AI-Supported Translation](https://help.sap.com/docs/leanix/ea/base-ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758e1767a441014b89cdbb68f4cded0__ai-supported_translation).
  * Position and order: On the Change position tab, you can change the order in which the field appears in a subsection as well as move it to a different subsection.
  * Options: On the Options tab, you can configure other parameters based on the field type.


![Configuring a Fact Sheet Field](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27432f3a7a441014a6a4fc38097f00d7_LowRes.gif)
Configuring a Fact Sheet Field
